"""empty message

Revision ID: c48c45d5402e
Revises: ead3644aab16
Create Date: 2023-12-16 16:05:24.293304

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'c48c45d5402e'
down_revision = 'ead3644aab16'
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index('filepaths_un', table_name='filepaths', schema='fansly', postgresql_where='((story_id IS NOT NULL) OR (post_id IS NOT NULL) OR (message_id IS NOT NULL) OR (mass_message_id IS NOT NULL) OR (media_id IS NOT NULL))')
    op.create_unique_constraint(None, 'filepaths', ['story_id', 'post_id', 'message_id', 'mass_message_id', 'media_id'], schema='fansly')
    op.drop_index('filepaths_un', table_name='filepaths', schema='onlyfans', postgresql_where='((story_id IS NOT NULL) OR (post_id IS NOT NULL) OR (message_id IS NOT NULL) OR (mass_message_id IS NOT NULL) OR (media_id IS NOT NULL))')
    op.create_unique_constraint(None, 'filepaths', ['story_id', 'post_id', 'message_id', 'mass_message_id', 'media_id'], schema='onlyfans')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, 'filepaths', schema='onlyfans', type_='unique')
    op.create_index('filepaths_un', 'filepaths', ['story_id', 'post_id', 'message_id', 'mass_message_id', 'media_id'], unique=False, schema='onlyfans', postgresql_where='((story_id IS NOT NULL) OR (post_id IS NOT NULL) OR (message_id IS NOT NULL) OR (mass_message_id IS NOT NULL) OR (media_id IS NOT NULL))')
    op.drop_constraint(None, 'filepaths', schema='fansly', type_='unique')
    op.create_index('filepaths_un', 'filepaths', ['story_id', 'post_id', 'message_id', 'mass_message_id', 'media_id'], unique=False, schema='fansly', postgresql_where='((story_id IS NOT NULL) OR (post_id IS NOT NULL) OR (message_id IS NOT NULL) OR (mass_message_id IS NOT NULL) OR (media_id IS NOT NULL))')
    # ### end Alembic commands ###



"""empty message

Revision ID: e0117f63ca57
Revises: fc8b9a0a819c
Create Date: 2023-12-16 16:38:58.174130

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'e0117f63ca57'
down_revision = 'fc8b9a0a819c'
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint('filepaths_un', 'filepaths', schema='fansly', type_='unique')
    op.create_unique_constraint(None, 'filepaths', ['message_id', 'media_id'], schema='fansly')
    op.create_unique_constraint(None, 'filepaths', ['mass_message_id', 'media_id'], schema='fansly')
    op.create_unique_constraint(None, 'filepaths', ['post_id', 'media_id'], schema='fansly')
    op.create_unique_constraint(None, 'filepaths', ['story_id', 'media_id'], schema='fansly')
    op.create_unique_constraint(None, 'filepaths', ['post_id', 'media_id'], schema='onlyfans')
    op.create_unique_constraint(None, 'filepaths', ['message_id', 'media_id'], schema='onlyfans')
    op.create_unique_constraint(None, 'filepaths', ['mass_message_id', 'media_id'], schema='onlyfans')
    op.create_unique_constraint(None, 'filepaths', ['story_id', 'media_id'], schema='onlyfans')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, 'filepaths', schema='onlyfans', type_='unique')
    op.drop_constraint(None, 'filepaths', schema='onlyfans', type_='unique')
    op.drop_constraint(None, 'filepaths', schema='onlyfans', type_='unique')
    op.drop_constraint(None, 'filepaths', schema='onlyfans', type_='unique')
    op.drop_constraint(None, 'filepaths', schema='fansly', type_='unique')
    op.drop_constraint(None, 'filepaths', schema='fansly', type_='unique')
    op.drop_constraint(None, 'filepaths', schema='fansly', type_='unique')
    op.drop_constraint(None, 'filepaths', schema='fansly', type_='unique')
    op.create_unique_constraint('filepaths_un', 'filepaths', ['story_id', 'post_id', 'message_id', 'mass_message_id', 'media_id'], schema='fansly')
    # ### end Alembic commands ###



"""empty message

Revision ID: bc4b94108111
Revises: e0117f63ca57
Create Date: 2023-12-16 16:53:24.055048

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'bc4b94108111'
down_revision = 'e0117f63ca57'
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint('content_media_asso_story_id_post_id_message_id_mass_message_key', 'content_media_asso', schema='fansly', type_='unique')
    op.create_unique_constraint(None, 'content_media_asso', ['story_id', 'media_id'], schema='fansly')
    op.create_unique_constraint(None, 'content_media_asso', ['message_id', 'media_id'], schema='fansly')
    op.create_unique_constraint(None, 'content_media_asso', ['post_id', 'media_id'], schema='fansly')
    op.create_unique_constraint(None, 'content_media_asso', ['mass_message_id', 'media_id'], schema='fansly')
    op.drop_constraint('content_media_asso_story_id_post_id_message_id_mass_message_key', 'content_media_asso', schema='onlyfans', type_='unique')
    op.create_unique_constraint(None, 'content_media_asso', ['story_id', 'media_id'], schema='onlyfans')
    op.create_unique_constraint(None, 'content_media_asso', ['post_id', 'media_id'], schema='onlyfans')
    op.create_unique_constraint(None, 'content_media_asso', ['message_id', 'media_id'], schema='onlyfans')
    op.create_unique_constraint(None, 'content_media_asso', ['mass_message_id', 'media_id'], schema='onlyfans')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, 'content_media_asso', schema='onlyfans', type_='unique')
    op.drop_constraint(None, 'content_media_asso', schema='onlyfans', type_='unique')
    op.drop_constraint(None, 'content_media_asso', schema='onlyfans', type_='unique')
    op.drop_constraint(None, 'content_media_asso', schema='onlyfans', type_='unique')
    op.create_unique_constraint('content_media_asso_story_id_post_id_message_id_mass_message_key', 'content_media_asso', ['story_id', 'post_id', 'message_id', 'mass_message_id', 'media_id'], schema='onlyfans')
    op.drop_constraint(None, 'content_media_asso', schema='fansly', type_='unique')
    op.drop_constraint(None, 'content_media_asso', schema='fansly', type_='unique')
    op.drop_constraint(None, 'content_media_asso', schema='fansly', type_='unique')
    op.drop_constraint(None, 'content_media_asso', schema='fansly', type_='unique')
    op.create_unique_constraint('content_media_asso_story_id_post_id_message_id_mass_message_key', 'content_media_asso', ['story_id', 'post_id', 'message_id', 'mass_message_id', 'media_id'], schema='fansly')
    # ### end Alembic commands ###



"""empty message

Revision ID: fc8b9a0a819c
Revises: c48c45d5402e
Create Date: 2023-12-16 16:25:40.257569

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "fc8b9a0a819c"
down_revision = "c48c45d5402e"
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(
        "filepaths_story_id_post_id_message_id_mass_message_id_media_key",
        "filepaths",
        schema="fansly",
        type_="unique",
    )
    op.create_unique_constraint(
        "filepaths_un",
        "filepaths",
        ["story_id", "post_id", "message_id", "mass_message_id", "media_id"],
        schema="fansly",
    )
    op.drop_constraint(
        "filepaths_story_id_post_id_message_id_mass_message_id_media_key",
        "filepaths",
        schema="onlyfans",
        type_="unique",
    )
    op.create_unique_constraint(
        "filepaths_un",
        "filepaths",
        ["story_id", "post_id", "message_id", "mass_message_id", "media_id"],
        schema="onlyfans",
    )
    op.execute(
        f"""
        ALTER TABLE onlyfans.filepaths
        ADD CONSTRAINT filepaths_un_check
        CHECK (
            (story_id IS NOT DISTINCT FROM story_id) AND
            (post_id IS NOT DISTINCT FROM post_id) AND
            (message_id IS NOT DISTINCT FROM message_id) AND
            (mass_message_id IS NOT DISTINCT FROM mass_message_id) AND
            (media_id IS NOT DISTINCT FROM media_id)
        )
        """
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint("filepaths_un", "filepaths", schema="onlyfans", type_="unique")
    op.create_unique_constraint(
        "filepaths_story_id_post_id_message_id_mass_message_id_media_key",
        "filepaths",
        ["story_id", "post_id", "message_id", "mass_message_id", "media_id"],
        schema="onlyfans",
    )
    op.execute(
        f"ALTER TABLE onlyfans.filepaths DROP CONSTRAINT IF EXISTS filepaths_un_check"
    )
    op.drop_constraint("filepaths_un", "filepaths", schema="fansly", type_="unique")
    op.create_unique_constraint(
        "filepaths_story_id_post_id_message_id_mass_message_id_media_key",
        "filepaths",
        ["story_id", "post_id", "message_id", "mass_message_id", "media_id"],
        schema="fansly",
    )
    op.execute(
        f"ALTER TABLE fansly.filepaths DROP CONSTRAINT IF EXISTS filepaths_un_check"
    )
    # ### end Alembic commands ###



"""empty message

Revision ID: ead3644aab16
Revises: fada8d5e0210
Create Date: 2023-12-16 15:47:28.103237

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'ead3644aab16'
down_revision = 'fada8d5e0210'
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index('filepaths_un', 'filepaths', ['story_id', 'post_id', 'message_id', 'mass_message_id', 'media_id'], unique=True, schema='fansly', postgresql_where='(story_id IS NOT NULL) OR (post_id IS NOT NULL) OR (message_id IS NOT NULL) OR (mass_message_id IS NOT NULL) OR (media_id IS NOT NULL)')
    op.create_index('filepaths_un', 'filepaths', ['story_id', 'post_id', 'message_id', 'mass_message_id', 'media_id'], unique=True, schema='onlyfans', postgresql_where='(story_id IS NOT NULL) OR (post_id IS NOT NULL) OR (message_id IS NOT NULL) OR (mass_message_id IS NOT NULL) OR (media_id IS NOT NULL)')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index('filepaths_un', table_name='filepaths', schema='onlyfans', postgresql_where='(story_id IS NOT NULL) OR (post_id IS NOT NULL) OR (message_id IS NOT NULL) OR (mass_message_id IS NOT NULL) OR (media_id IS NOT NULL)')
    op.drop_index('filepaths_un', table_name='filepaths', schema='fansly', postgresql_where='(story_id IS NOT NULL) OR (post_id IS NOT NULL) OR (message_id IS NOT NULL) OR (mass_message_id IS NOT NULL) OR (media_id IS NOT NULL)')
    # ### end Alembic commands ###



"""empty message

Revision ID: fada8d5e0210
Revises: 86985996f9b9
Create Date: 2023-12-14 12:08:53.519490

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'fada8d5e0210'
down_revision = '86985996f9b9'
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('favorite_users',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('user_id', sa.BigInteger(), nullable=False),
    sa.Column('notification', sa.Boolean(), server_default='true', nullable=False),
    sa.ForeignKeyConstraint(['user_id'], ['fansly.users.id'], ),
    sa.PrimaryKeyConstraint('id'),
    sa.UniqueConstraint('user_id'),
    schema='fansly'
    )
    op.create_table('favorite_users',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('user_id', sa.BigInteger(), nullable=False),
    sa.Column('notification', sa.Boolean(), server_default='true', nullable=False),
    sa.ForeignKeyConstraint(['user_id'], ['onlyfans.users.id'], ),
    sa.PrimaryKeyConstraint('id'),
    sa.UniqueConstraint('user_id'),
    schema='onlyfans'
    )
    op.add_column('jobs', sa.Column('priority', sa.Boolean(), server_default='false', nullable=False), schema='fansly')
    op.add_column('jobs', sa.Column('priority', sa.Boolean(), server_default='false', nullable=False), schema='onlyfans')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('jobs', 'priority', schema='onlyfans')
    op.drop_column('jobs', 'priority', schema='fansly')
    op.drop_table('favorite_users', schema='onlyfans')
    op.drop_table('favorite_users', schema='fansly')
    # ### end Alembic commands ###
